@@ -477,7 +477,7 @@ test -x $soundtest_prog  && soundtest_entry=$(entry \
 menumanager_prog=/usr/local/bin/menu_manager.sh
 test -x $menumanager_prog && menumanager_entry=$(entry \
     $ICONS/menu-editor.png \
-    "gksu menu_manager.sh &" \
+    "sudo menu_manager.sh &" \
     $"Menu Editor")
 
 usermanager_prog=/usr/local/bin/user-management
